@@ -6,7 +6,6 @@ import (
 	"crypto/ed25519"
 	crand "crypto/rand"
 	"encoding/base64"
-	"encoding/json"
 	"fmt"
 	"io"
 	"os"
@@ -20,7 +19,7 @@ import (
 	"github.com/mdp/qrterminal/v3"
 	"moul.io/godev"
 
-	"berty.tech/berty/v2/go/internal/bertylinks"
+	"berty.tech/berty/v2/go/pkg/bertylinks"
 	"berty.tech/berty/v2/go/pkg/bertyvcissuer"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
@@ -197,11 +196,6 @@ func commandList() []*command {
 			help:  "Registers current group for replication using specified token",
 			cmd:   replGroup,
 		},
-		{
-			title: "reply-options",
-			help:  `Sends a list of quick responses from JSON: [{"display": "Text offering a *yes* option", "payload": "yes"}]`,
-			cmd:   sendReplyOptions,
-		},
 		{
 			title: "export",
 			help:  `Saves an export of the current instance to the specified path`,
@@ -226,22 +220,6 @@ func commandList() []*command {
 	}
 }
 
-func sendReplyOptions(ctx context.Context, v *groupView, cmd string) error {
-	options := []*messengertypes.ReplyOption{}
-	if err := json.Unmarshal([]byte(cmd), &options); err != nil {
-		return err
-	}
-
-	_, err := v.v.messenger.SendReplyOptions(ctx, &messengertypes.SendReplyOptions_Request{
-		GroupPK: v.g.PublicKey,
-		Options: &messengertypes.AppMessage_ReplyOptions{
-			Options: options,
-		},
-	})
-
-	return err
-}
-
 func credentialVerificationInit(ctx context.Context, v *groupView, service string) error {
 	// TODO: move this to bertyprotocol
 	// FIXME: use a non volatile identity
