@@ -21,11 +21,12 @@ import (
 	"go.uber.org/zap"
 	"google.golang.org/grpc"
 	"google.golang.org/grpc/connectivity"
+	"google.golang.org/grpc/credentials/insecure"
 	"moul.io/srand"
 	"moul.io/u"
 	"moul.io/zapconfig"
 
-	"berty.tech/berty/v2/go/internal/bertylinks"
+	"berty.tech/berty/v2/go/pkg/bertylinks"
 	"berty.tech/berty/v2/go/pkg/bertyversion"
 	"berty.tech/berty/v2/go/pkg/messengertypes"
 )
@@ -150,7 +151,7 @@ func welcomebot() error {
 
 	// init messenger gRPC client
 	{
-		cc, err := grpc.DialContext(ctx, *nodeAddr, grpc.WithInsecure())
+		cc, err := grpc.DialContext(ctx, *nodeAddr, grpc.WithTransportCredentials(insecure.NewCredentials()))
 		if err != nil {
 			return fmt.Errorf("unable to connect with remote berty messenger node: %w", err)
 		}
@@ -354,7 +355,7 @@ func (bot *Bot) handleUserMessageInteractionUpdated(ctx context.Context, _ *mess
 		}
 		// auto-reply to user's messages
 		answer := getRandomReply()
-		if err := bot.interactUserMessage(ctx, answer, interaction.ConversationPublicKey, defaultReplyOption()); err != nil {
+		if err := bot.interactUserMessage(ctx, answer, interaction.ConversationPublicKey); err != nil {
 			return fmt.Errorf("interact user message failed: %w", err)
 		}
 	}
@@ -373,11 +374,7 @@ func doStep0(ctx context.Context, conv *Conversation, bot *Bot, receivedMessage
 		body := `Okay, perfect! 🤙
 Would you like me to invite you to a group chat to test multimember conversations?
 Type 'yes' to receive it! 💌`
-		options := []*messengertypes.ReplyOption{
-			{Payload: "yes", Display: "Sure, go for it!"},
-			{Payload: "no", Display: "Show me all you can do instead!"},
-		}
-		if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey, options); err != nil {
+		if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey); err != nil {
 			return false, fmt.Errorf("interact user message failed: %w", err)
 		}
 		return true, nil
@@ -396,7 +393,7 @@ func doStep1(ctx context.Context, conv *Conversation, bot *Bot, receivedMessage
 		body := `Okay, I'm inviting you! 🤝
 I'll also invite some staff members to join the group!
 I’m cool, but humans are sometimes cooler than me… 🤖 ❤️`
-		if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey, nil); err != nil {
+		if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey); err != nil {
 			return false, fmt.Errorf("interact user message failed: %w", err)
 		}
 
@@ -426,7 +423,7 @@ I’m cool, but humans are sometimes cooler than me… 🤖 ❤️`
 		body = `Okay, done! 👏 👍
 Welcome and thanks for joining our community. You're part of the revolution now! 🔥
 Type /help when you need info about available test commands! 📖`
-		if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey, defaultReplyOption()); err != nil {
+		if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey); err != nil {
 			return false, fmt.Errorf("interact user message failed: %w", err)
 		}
 		bot.logger.Info("scenario finished")
@@ -440,7 +437,6 @@ func doStep2(ctx context.Context, _ *Conversation, bot *Bot, receivedMessage *me
 	unlock()
 	msg := receivedMessage.GetBody()
 	if msg[0] == '/' {
-		options := defaultReplyOption()
 		switch strings.ToLower(msg[1:]) {
 		case "help":
 			body := `In this conversation, you can type all these commands :
@@ -449,7 +445,7 @@ func doStep2(ctx context.Context, _ *Conversation, bot *Bot, receivedMessage *me
 /demo share
 /demo contact "Here is the QR code of manfred, just add him!"
 /demo version`
-			if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey, options); err != nil {
+			if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey); err != nil {
 				return false, fmt.Errorf("interact user message failed: %w", err)
 			}
 		case "demo version":
@@ -459,12 +455,12 @@ func doStep2(ctx context.Context, _ *Conversation, bot *Bot, receivedMessage *me
 			} else {
 				body = "berty " + bertyversion.Version + " https://github.com/berty/berty/commits/" + bertyversion.VcsRef + "\n" + runtime.Version()
 			}
-			if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey, options); err != nil {
+			if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey); err != nil {
 				return false, fmt.Errorf("interact user message failed: %w", err)
 			}
 		default:
 			body := fmt.Sprintf("Sorry but the command %q is not yet known.", msg)
-			if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey, options); err != nil {
+			if err := bot.interactUserMessage(ctx, body, interaction.ConversationPublicKey); err != nil {
 				return false, fmt.Errorf("interact user message failed: %w", err)
 			}
 		}
@@ -532,7 +528,7 @@ For the moment i can't send a group invitation so i share the link of the conver
 			userName,
 			conversation.GetLink(),
 		)
-		if err := bot.interactUserMessage(ctx, body, bot.store.StaffConvPK, nil); err != nil {
+		if err := bot.interactUserMessage(ctx, body, bot.store.StaffConvPK); err != nil {
 			return fmt.Errorf("interact user message failed: %w", err)
 		}
 
@@ -565,11 +561,7 @@ For the moment i can't send a group invitation so i share the link of the conver
 I’m here to help you with the onboarding process.
 Let's test out some features together!
 Just type 'yes' to let me know you copy that.`
-		options := []*messengertypes.ReplyOption{
-			{Payload: "yes", Display: "Sure, go for it!"},
-			{Payload: "no", Display: "Show me all you can do instead!"},
-		}
-		if err := bot.interactUserMessage(ctx, body, conversation.GetPublicKey(), options); err != nil {
+		if err := bot.interactUserMessage(ctx, body, conversation.GetPublicKey()); err != nil {
 			return fmt.Errorf("interact user message failed: %w", err)
 		}
 		return nil
@@ -580,7 +572,7 @@ Just type 'yes' to let me know you copy that.`
 
 // internal stuff
 
-func (bot *Bot) interactUserMessage(ctx context.Context, body string, conversationPK string, replyOption []*messengertypes.ReplyOption) error {
+func (bot *Bot) interactUserMessage(ctx context.Context, body string, conversationPK string) error {
 	time.Sleep(3 * time.Second)
 	userMessage, err := proto.Marshal(&messengertypes.AppMessage_UserMessage{Body: body})
 	if err != nil {
@@ -595,25 +587,6 @@ func (bot *Bot) interactUserMessage(ctx context.Context, body string, conversati
 		return fmt.Errorf("interact user message failed: %w", err)
 	}
 
-	// send reply options
-	{
-		convPKBytes, err := base64.RawURLEncoding.DecodeString(conversationPK)
-		if err != nil {
-			return fmt.Errorf("conversation convPK failed: %w", err)
-		}
-		if replyOption != nil {
-			_, err := bot.client.SendReplyOptions(ctx, &messengertypes.SendReplyOptions_Request{
-				GroupPK: convPKBytes,
-				Options: &messengertypes.AppMessage_ReplyOptions{
-					Options: replyOption,
-				},
-			})
-			if err != nil {
-				return fmt.Errorf("interact reply options failed: %w", err)
-			}
-		}
-	}
-
 	return nil
 }
 
@@ -671,13 +644,6 @@ func safeDefaultDisplayName() string {
 	return fmt.Sprintf("%s (Welcome Bot)", name)
 }
 
-func defaultReplyOption() []*messengertypes.ReplyOption {
-	return []*messengertypes.ReplyOption{
-		{Payload: "/help", Display: "Display Welcome Bot commands"},
-		{Payload: "/demo version", Display: "What is the demo version?"},
-	}
-}
-
 func getRandomReply() string {
 	available := []string{
 		"Welcome to Berty v1!",
