@@ -12,23 +12,23 @@ import (
 	"sync"
 	"time"
 
-	ipfs_mobile "github.com/ipfs-shipyard/gomobile-ipfs/go/pkg/ipfsmobile"
 	datastore "github.com/ipfs/go-datastore"
-	ipfs_cfg "github.com/ipfs/go-ipfs-config"
-	ipfs_util "github.com/ipfs/go-ipfs/cmd/ipfs/util"
-	ipfs_core "github.com/ipfs/go-ipfs/core"
-	ipfs_p2p "github.com/ipfs/go-ipfs/core/node/libp2p"
-	ipfs_repo "github.com/ipfs/go-ipfs/repo"
+	ipfs_util "github.com/ipfs/kubo/cmd/ipfs/util"
+	ipfs_cfg "github.com/ipfs/kubo/config"
+	ipfs_core "github.com/ipfs/kubo/core"
+	ipfs_p2p "github.com/ipfs/kubo/core/node/libp2p"
+	ipfs_repo "github.com/ipfs/kubo/repo"
 	libp2p "github.com/libp2p/go-libp2p"
-	p2p_disc "github.com/libp2p/go-libp2p-core/discovery"
-	"github.com/libp2p/go-libp2p-core/host"
-	"github.com/libp2p/go-libp2p-core/peer"
-	peerstore "github.com/libp2p/go-libp2p-core/peerstore"
-	p2p_routing "github.com/libp2p/go-libp2p-core/routing"
-	discovery "github.com/libp2p/go-libp2p-discovery"
 	p2p_dht "github.com/libp2p/go-libp2p-kad-dht"
 	pubsub "github.com/libp2p/go-libp2p-pubsub"
-	"github.com/libp2p/go-tcp-transport"
+	"github.com/libp2p/go-libp2p/core/host"
+	"github.com/libp2p/go-libp2p/core/peer"
+	"github.com/libp2p/go-libp2p/core/peerstore"
+	p2p_routing "github.com/libp2p/go-libp2p/core/routing"
+	"github.com/libp2p/go-libp2p/p2p/discovery/backoff"
+	"github.com/libp2p/go-libp2p/p2p/host/autorelay"
+	connmgr "github.com/libp2p/go-libp2p/p2p/net/connmgr"
+	tcpt "github.com/libp2p/go-libp2p/p2p/transport/tcp"
 	ma "github.com/multiformats/go-multiaddr"
 	manet "github.com/multiformats/go-multiaddr/net"
 	"go.uber.org/zap"
@@ -38,11 +38,12 @@ import (
 	"berty.tech/berty/v2/go/internal/config"
 	"berty.tech/berty/v2/go/internal/datastoreutil"
 	"berty.tech/berty/v2/go/internal/ipfsutil"
+	ipfs_mobile "berty.tech/berty/v2/go/internal/ipfsutil/mobile"
 	"berty.tech/berty/v2/go/internal/logutil"
 	mc "berty.tech/berty/v2/go/internal/multipeer-connectivity-driver"
 	proximity "berty.tech/berty/v2/go/internal/proximitytransport"
 	"berty.tech/berty/v2/go/internal/rendezvous"
-	"berty.tech/berty/v2/go/internal/tinder"
+	tinder "berty.tech/berty/v2/go/internal/tinder"
 	"berty.tech/berty/v2/go/pkg/bertyprotocol"
 	"berty.tech/berty/v2/go/pkg/errcode"
 	ipfswebui "berty.tech/ipfs-webui-packed"
@@ -104,11 +105,10 @@ func (m *Manager) SetupLocalIPFSFlags(fs *flag.FlagSet) {
 	fs.BoolVar(&m.Node.Protocol.TinderDHTDriver, FlagNameP2PTinderDHTDriver, true, "if true dht driver will be enable for tinder")
 	fs.BoolVar(&m.Node.Protocol.TinderRDVPDriver, FlagNameP2PTinderRDVPDriver, true, "if true rdvp driver will be enable for tinder")
 	fs.BoolVar(&m.Node.Protocol.TinderLocalDiscoveryDriver, FlagNameP2PTinderLocalDiscoveryDriver, true, "if true localdiscovery driver will be enable for tinder")
-	fs.BoolVar(&m.Node.Protocol.DisableDiscoverFilterAddrs, FlagNameP2PDisableDiscoverAddrsFilter, false, "dont filter private addrs on discovery service")
 	fs.BoolVar(&m.Node.Protocol.AutoRelay, "p2p.autorelay", true, "enable autorelay, force private reachability")
 	fs.StringVar(&m.Node.Protocol.StaticRelays, FlagNameP2PStaticRelays, KeywordDefault, "list of static relay maddrs, `:default:` will use statics relays from the config")
-	fs.DurationVar(&m.Node.Protocol.MinBackoff, "p2p.min-backoff", time.Second, "minimum p2p backoff duration")
-	fs.DurationVar(&m.Node.Protocol.MaxBackoff, "p2p.max-backoff", time.Minute*10, "maximum p2p backoff duration")
+	fs.DurationVar(&m.Node.Protocol.MinBackoff, "p2p.min-backoff", time.Second*10, "minimum p2p backoff duration")
+	fs.DurationVar(&m.Node.Protocol.MaxBackoff, "p2p.max-backoff", time.Hour, "maximum p2p backoff duration")
 	fs.DurationVar(&m.Node.Protocol.PollInterval, "p2p.poll-interval", pubsub.DiscoveryPollInterval, "how long the discovery system will waits for more peers")
 	fs.StringVar(&m.Node.Protocol.RdvpMaddrs, FlagNameP2PRDVP, KeywordDefault, "list of rendezvous point maddr, `:dev:` will add the default devs servers, `:none:` will disable rdvp")
 	fs.BoolVar(&m.Node.Protocol.Ble.Enable, FlagNameP2PBLE, false, "if true Bluetooth Low Energy will be enabled")
@@ -180,7 +180,7 @@ func (m *Manager) getLocalIPFS() (ipfsutil.ExtendedCoreAPI, *ipfs_core.IpfsNode,
 
 	var routing ipfs_p2p.RoutingOption
 	if dhtmode > 0 && !m.Node.Protocol.DisableIPFSNetwork {
-		dhtopts := []p2p_dht.Option{p2p_dht.Concurrency(5)}
+		dhtopts := []p2p_dht.Option{p2p_dht.Concurrency(1)}
 
 		if !m.Node.Protocol.DHTRandomWalk {
 			dhtopts = append(dhtopts, p2p_dht.DisableAutoRefresh())
@@ -287,7 +287,11 @@ func (m *Manager) getLocalIPFS() (ipfsutil.ExtendedCoreAPI, *ipfs_core.IpfsNode,
 	// serve webui
 	if addr := m.Node.Protocol.IPFSWebUIListener; addr != "" {
 		dir := http.FileServer(ipfswebui.Dir())
-		server := &http.Server{Addr: addr, Handler: dir}
+		server := &http.Server{
+			Addr:              addr,
+			Handler:           dir,
+			ReadHeaderTimeout: time.Second * 5,
+		}
 
 		m.workers.Add(func() error {
 			var err error
@@ -303,12 +307,35 @@ func (m *Manager) getLocalIPFS() (ipfsutil.ExtendedCoreAPI, *ipfs_core.IpfsNode,
 		})
 	}
 
-	psapi := ipfsutil.NewPubSubAPI(m.getContext(), logger.Named("ps"), m.Node.Protocol.discovery, m.Node.Protocol.pubsub)
+	psapi := ipfsutil.NewPubSubAPI(m.getContext(), logger.Named("ps"), m.Node.Protocol.pubsub)
 	m.Node.Protocol.ipfsAPI = ipfsutil.InjectPubSubCoreAPIExtendedAdapter(m.Node.Protocol.ipfsAPI, psapi)
 
 	// enable conn logger
 	ipfsutil.EnableConnLogger(m.getContext(), logger, m.Node.Protocol.ipfsNode.PeerHost)
 
+	lm := m.getLifecycleManager()
+
+	serverRng := mrand.New(mrand.NewSource(srand.MustSecure())) // nolint:gosec // we need to use math/rand here, but it is seeded from crypto/rand
+	backoffstrat := backoff.NewExponentialBackoff(
+		time.Second,
+		time.Minute*10,
+		backoff.FullJitter,
+		time.Second, 5.0, 0, serverRng)
+
+	peering := ipfsutil.NewPeeringService(
+		logger.Named("peering"), m.Node.Protocol.ipfsNode.PeerHost, backoffstrat,
+	)
+	if err := peering.Start(); err != nil {
+		return nil, nil, errcode.ErrIPFSInit.Wrap(err)
+	}
+	// enable lifecycle conn
+	m.Node.Protocol.connlifecycle, err = ipfsutil.NewConnLifecycle(
+		ctx, logger.Named("ipfs-lc"), m.Node.Protocol.ipfsNode.PeerHost, peering, lm,
+	)
+	if err != nil {
+		return nil, nil, errcode.ErrIPFSInit.Wrap(err)
+	}
+
 	// register metrics
 	if m.Metrics.Listener != "" {
 		registry, err := m.getMetricsRegistry()
@@ -352,19 +379,23 @@ func (m *Manager) setupIPFSRepo(ctx context.Context) (*ipfs_mobile.RepoMobile, e
 		return nil, errcode.ErrKeystoreGet.Wrap(err)
 	}
 
-	storageSalt, err := m.GetAccountStorageSalt()
+	ipfsDatastoreSalt, err := m.GetAccountIPFSDatastoreSalt()
 	if err != nil {
 		return nil, errcode.ErrKeystoreGet.Wrap(err)
 	}
 
-	dbPath := filepath.Join(m.Datastore.Dir, "ipfs.sqlite")
+	appDir, err := m.getAppDataDir()
+	if err != nil {
+		return nil, errcode.TODO.Wrap(err)
+	}
+	dbPath := filepath.Join(appDir, "ipfs.sqlite")
 
-	repo, err = ipfsutil.LoadRepoFromPath(dbPath, storageKey, storageSalt)
+	repo, err = ipfsutil.LoadRepoFromPath(dbPath, storageKey, ipfsDatastoreSalt)
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 	}
 
-	repo, err = m.resetRepoIdentityIfExpired(ctx, repo, dbPath, storageKey, storageSalt)
+	repo, err = m.resetRepoIdentityIfExpired(ctx, repo, dbPath, storageKey, ipfsDatastoreSalt)
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 	}
@@ -372,13 +403,13 @@ func (m *Manager) setupIPFSRepo(ctx context.Context) (*ipfs_mobile.RepoMobile, e
 	return ipfs_mobile.NewRepoMobile(dbPath, repo), nil
 }
 
-func (m *Manager) resetRepoIdentityIfExpired(ctx context.Context, repo ipfs_repo.Repo, dbPath string, storageKey []byte, storageSalt []byte) (ipfs_repo.Repo, error) {
+func (m *Manager) resetRepoIdentityIfExpired(ctx context.Context, repo ipfs_repo.Repo, dbPath string, storageKey []byte, ipfsDatastoreSalt []byte) (ipfs_repo.Repo, error) {
 	rootDS, err := m.getRootDatastore()
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 	}
 
-	lastUpdate := time.Now()
+	var lastUpdate time.Time
 	lastUpdateKey := datastore.NewKey(ipfsIdentityLastUpdateKey)
 	lastUpdateRaw, err := rootDS.Get(ctx, lastUpdateKey)
 	switch err {
@@ -388,8 +419,8 @@ func (m *Manager) resetRepoIdentityIfExpired(ctx context.Context, repo ipfs_repo
 			return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 		}
 	case datastore.ErrNotFound:
-		// key does not exist, force recreation
-		lastUpdate = time.Time{}
+		// key does not exist, do nothing
+		break
 	default:
 		return nil, errcode.ErrIPFSSetupRepo.Wrap(err)
 	}
@@ -400,7 +431,7 @@ func (m *Manager) resetRepoIdentityIfExpired(ctx context.Context, repo ipfs_repo
 	}
 
 	if lastUpdate.Before(time.Now().Add(-rendezvousRotationBase)) {
-		repo, err = ipfsutil.ResetExistingRepoIdentity(repo, dbPath, storageKey, storageSalt)
+		repo, err = ipfsutil.ResetExistingRepoIdentity(repo, dbPath, storageKey, ipfsDatastoreSalt)
 		if err != nil {
 			return nil, errcode.ErrInternal.Wrap(err)
 		}
@@ -445,13 +476,31 @@ func (m *Manager) setupIPFSConfig(cfg *ipfs_cfg.Config) ([]libp2p.Option, error)
 		cfg.Addresses.NoAnnounce = strings.Split(m.Node.Protocol.NoAnnounce, ",")
 	}
 
-	if m.Node.Protocol.HighWatermark > 0 {
-		cfg.Swarm.ConnMgr.HighWater = m.Node.Protocol.HighWatermark
+	// disable original connection manager
+	cfg.Swarm.ConnMgr.Type = "none"
+
+	// configure custom conn manager
+	cm, err := connmgr.NewConnManager(
+		cfg.Swarm.ConnMgr.LowWater, cfg.Swarm.ConnMgr.HighWater, connmgr.WithGracePeriod(ipfs_cfg.DefaultConnMgrGracePeriod),
+	)
+	if err != nil {
+		return nil, errcode.ErrIPFSSetupConfig.Wrap(err)
 	}
 
-	if m.Node.Protocol.LowWatermark > 0 {
-		cfg.Swarm.ConnMgr.LowWater = m.Node.Protocol.LowWatermark
-	}
+	// wrap conn manager
+	m.Node.Protocol.connmngr = ipfsutil.NewBertyConnManager(logger.Named("connmgr"), cm)
+
+	// add our connection manager
+	p2popts = append(p2popts, libp2p.ConnectionManager(m.Node.Protocol.connmngr))
+
+	// @NOTE(gfanton): we don't have to set this since we use a custom connmngr
+	// if m.Node.Protocol.HighWatermark > 0 {
+	// 	cfg.Swarm.ConnMgr.HighWater = m.Node.Protocol.HighWatermark
+	// }
+
+	// if m.Node.Protocol.LowWatermark > 0 {
+	// 	cfg.Swarm.ConnMgr.LowWater = m.Node.Protocol.LowWatermark
+	// }
 
 	if m.Node.Protocol.DisableIPFSNetwork {
 		// Disable IP transports
@@ -522,26 +571,26 @@ func (m *Manager) setupIPFSConfig(cfg *ipfs_cfg.Config) ([]libp2p.Option, error)
 	// enable mdns
 	cfg.Discovery.MDNS.Enabled = false
 
-	// enable auto relay
-	if m.Node.Protocol.AutoRelay {
-		cfg.Swarm.RelayClient.Enabled = ipfs_cfg.True
-	} else {
-		cfg.Swarm.RelayClient.Enabled = ipfs_cfg.False
-		cfg.Swarm.Transports.Network.Relay = ipfs_cfg.False
-	}
+	// disable managed auto relay
+	cfg.Swarm.RelayClient.Enabled = ipfs_cfg.False
+	cfg.Swarm.Transports.Network.Relay = ipfs_cfg.True
 
 	pis, err := m.getStaticRelays()
 	if err != nil {
 		return nil, errcode.ErrIPFSSetupConfig.Wrap(err)
 	}
 
+	// add static relay
 	if len(pis) > 0 {
 		peers := make([]peer.AddrInfo, len(pis))
 		for i, p := range pis {
 			peers[i] = *p
 		}
 
-		p2popts = append(p2popts, libp2p.StaticRelays(peers))
+		p2popts = append(p2popts, libp2p.EnableAutoRelay(
+			autorelay.WithStaticRelays(peers),
+			autorelay.WithCircuitV1Support(),
+		))
 	}
 
 	// prefill peerstore with known rdvp servers
@@ -557,8 +606,8 @@ func (m *Manager) setupIPFSConfig(cfg *ipfs_cfg.Config) ([]libp2p.Option, error)
 	// @NOTE(gfanton): disable tcp transport so we can init a custom transport
 	// with reusport disable
 	cfg.Swarm.Transports.Network.TCP = ipfs_cfg.False
-	p2popts = append(p2popts, libp2p.Transport(tcp.NewTCPTransport,
-		tcp.DisableReuseport(),
+	p2popts = append(p2popts, libp2p.Transport(tcpt.NewTCPTransport,
+		tcpt.DisableReuseport(),
 	))
 
 	return p2popts, nil
@@ -586,10 +635,15 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 		}
 	}
 
+	// register berty connmngr bus event
+	if err := m.Node.Protocol.connmngr.RegisterEventBus(h.EventBus()); err != nil {
+		return errcode.ErrIPFSSetupHost.Wrap(err)
+	}
+
 	rng := mrand.New(mrand.NewSource(srand.MustSecure())) // nolint:gosec // we need to use math/rand here, but it is seeded from crypto/rand
 
 	// configure tinder drivers
-	var drivers []*tinder.Driver
+	var drivers []tinder.IDriver
 
 	// localdiscovery driver
 	if m.Node.Protocol.TinderLocalDiscoveryDriver {
@@ -598,65 +652,39 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 			return errcode.ErrIPFSSetupHost.Wrap(err)
 		}
 
-		filter := tinder.PrivateAddrOnly
-		if m.Node.Protocol.DisableDiscoverFilterAddrs {
-			filter = tinder.NoFilter
-		}
-
-		drivers = append(drivers,
-			tinder.NewDriverFromUnregisterDiscovery(tinder.LocalDiscoveryName, m.Node.Protocol.localdisc, filter))
+		drivers = append(drivers, m.Node.Protocol.localdisc)
 	}
 
 	// rdvp driver
 	if m.Node.Protocol.TinderRDVPDriver {
-		rdvpfilter := tinder.PublicAddrsOnly
-		if m.Node.Protocol.DisableDiscoverFilterAddrs {
-			rdvpfilter = tinder.NoFilter
-		}
-
 		if lenrdvpeers := len(rdvpeers); lenrdvpeers > 0 {
 			for _, peer := range rdvpeers {
 				h.Peerstore().AddAddrs(peer.ID, peer.Addrs, peerstore.PermanentAddrTTL)
-				udisc := tinder.NewRendezvousDiscovery(logger, h, peer.ID, rng)
+				m.Node.Protocol.emitterclient = rendezvous.NewEmitterClient(&rendezvous.EmitterClientOptions{
+					Logger: logger,
+				})
 
-				name := fmt.Sprintf("rdvp#%.6s", peer.ID)
-
-				drivers = append(drivers,
-					tinder.NewDriverFromUnregisterDiscovery(name, udisc, rdvpfilter))
+				// mqttclient := rendezvous.NewMQTTClient(logger, baseopts)
+				udisc := tinder.NewRendezvousDiscovery(logger, h, peer.ID, rng, m.Node.Protocol.emitterclient)
+				drivers = append(drivers, udisc)
 			}
 		}
 	}
 
 	// dht driver
 	if m.Node.Protocol.DHT != "none" && m.Node.Protocol.TinderDHTDriver {
-		dhtfilter := tinder.PublicAddrsOnly
-		if m.Node.Protocol.DisableDiscoverFilterAddrs {
-			dhtfilter = tinder.NoFilter
-		}
-
-		// dht driver
-		drivers = append(drivers, tinder.NewDriverFromRouting("dht", r, dhtfilter))
+		drivers = append(drivers, tinder.NewRoutingDiscoveryDriver("dht", r))
 	}
 
 	serverRng := mrand.New(mrand.NewSource(srand.MustSecure())) // nolint:gosec // we need to use math/rand here, but it is seeded from crypto/rand
 
-	backoffstrat := discovery.NewExponentialBackoff(
+	backoffstrat := backoff.NewExponentialBackoff(
 		m.Node.Protocol.MinBackoff,
 		m.Node.Protocol.MaxBackoff,
-		discovery.FullJitter,
-		time.Second, 5.0, 0, serverRng)
+		backoff.FullJitter,
+		time.Second, 10.0, 0, serverRng)
 
-	tinderOpts := &tinder.Opts{
-		Logger:                 logger,
-		AdvertiseResetInterval: time.Minute * 2,
-		FindPeerResetInterval:  time.Minute * 2,
-		AdvertiseGracePeriod:   time.Minute,
-		BackoffStrategy: &tinder.BackoffOpts{
-			StratFactory: backoffstrat,
-		},
-	}
-
-	m.Node.Protocol.discovery, err = tinder.NewService(tinderOpts, h, drivers...)
+	m.Node.Protocol.tinder, err = tinder.NewService(h, logger, drivers...)
 	if err != nil {
 		return errcode.ErrIPFSSetupHost.Wrap(err)
 	}
@@ -665,7 +693,7 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 	go func() {
 		<-m.getContext().Done()
 
-		m.Node.Protocol.discovery.Close()
+		m.Node.Protocol.tinder.Close()
 
 		if m.Node.Protocol.localdisc != nil {
 			m.Node.Protocol.localdisc.Close()
@@ -676,32 +704,15 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 		}
 	}()
 
-	pt, err := ipfsutil.NewPubsubMonitor(logger, h)
-	if err != nil {
-		return errcode.ErrIPFSSetupHost.Wrap(err)
-	}
-
 	cacheSize := 100
 	dialTimeout := time.Second * 20
-	backoffconnector := func(host host.Host) (*discovery.BackoffConnector, error) {
-		return discovery.NewBackoffConnector(host, cacheSize, dialTimeout, backoffstrat)
+	backoffconnector := func(host host.Host) (*backoff.BackoffConnector, error) {
+		return backoff.NewBackoffConnector(host, cacheSize, dialTimeout, backoffstrat)
 	}
 
 	popts := []pubsub.Option{
 		pubsub.WithMessageSigning(true),
 		pubsub.WithPeerExchange(true),
-		pt.EventTracerOption(),
-	}
-
-	var disc p2p_disc.Discovery
-	if m.Node.Protocol.TinderDiscover {
-		// filter localdiscovery from drivers since pubsub automatically share topic between connected peers
-		disc = tinder.NewFilterDriverDiscovery(m.Node.Protocol.discovery, tinder.LocalDiscoveryName)
-	} else {
-		disc = tinder.DriverDiscovery{
-			Discoverer: tinder.NoopDiscovery,
-			Advertiser: m.Node.Protocol.discovery,
-		}
 	}
 
 	// rp, err := m.getRotationInterval()
@@ -710,7 +721,9 @@ func (m *Manager) configIPFSRouting(h host.Host, r p2p_routing.Routing) error {
 	// }
 
 	// disc = tinder.NewRotationDiscovery(logger.Named("rotation"), disc, rp)
-	popts = append(popts, pubsub.WithDiscovery(disc, pubsub.WithDiscoverConnector(backoffconnector)))
+	m.Node.Protocol.discAdaptater = tinder.NewDiscoveryAdaptater(logger.Named("disc"), m.Node.Protocol.tinder)
+	popts = append(popts, pubsub.WithDiscovery(
+		m.Node.Protocol.discAdaptater, pubsub.WithDiscoverConnector(backoffconnector)))
 
 	// pubsub.DiscoveryPollInterval = m.Node.Protocol.PollInterval
 	m.Node.Protocol.pubsub, err = pubsub.NewGossipSub(m.getContext(), h, popts...)
