@@ -6,10 +6,13 @@ import (
 	"fmt"
 	"os"
 	"os/user"
+	"strings"
 
 	grpcgw "github.com/grpc-ecosystem/grpc-gateway/runtime"
 	datastore "github.com/ipfs/go-datastore"
+	"go.uber.org/zap"
 	"google.golang.org/grpc"
+	"google.golang.org/grpc/credentials/insecure"
 	"gorm.io/gorm"
 
 	"berty.tech/berty/v2/go/internal/accountutils"
@@ -19,6 +22,7 @@ import (
 	"berty.tech/berty/v2/go/internal/grpcutil"
 	"berty.tech/berty/v2/go/internal/ipfsutil"
 	"berty.tech/berty/v2/go/internal/lifecycle"
+	"berty.tech/berty/v2/go/internal/logutil"
 	"berty.tech/berty/v2/go/pkg/bertymessenger"
 	"berty.tech/berty/v2/go/pkg/bertyprotocol"
 	"berty.tech/berty/v2/go/pkg/errcode"
@@ -195,7 +199,7 @@ func (m *Manager) getLocalProtocolServer() (bertyprotocol.Service, error) {
 		opts := bertyprotocol.Opts{
 			Host:             m.Node.Protocol.ipfsNode.PeerHost,
 			PubSub:           m.Node.Protocol.pubsub,
-			TinderDriver:     m.Node.Protocol.discovery,
+			TinderService:    m.Node.Protocol.tinder,
 			IpfsCoreAPI:      m.Node.Protocol.ipfsAPI,
 			Logger:           logger,
 			RootDatastore:    rootDS,
@@ -205,7 +209,7 @@ func (m *Manager) getLocalProtocolServer() (bertyprotocol.Service, error) {
 			GRPCInsecureMode: m.Node.Protocol.ServiceInsecureMode,
 		}
 
-		m.Node.Protocol.server, err = bertyprotocol.New(m.getContext(), opts)
+		m.Node.Protocol.server, err = bertyprotocol.New(opts)
 		if err != nil {
 			return nil, errcode.TODO.Wrap(err)
 		}
@@ -237,7 +241,7 @@ func (m *Manager) getGRPCClientConn() (*grpc.ClientConn, error) {
 	clientOpts := []grpc.DialOption(nil)
 
 	if m.Node.GRPC.RemoteAddr != "" {
-		clientOpts = append(clientOpts, grpc.WithInsecure()) // make a flag for this?
+		clientOpts = append(clientOpts, grpc.WithTransportCredentials(insecure.NewCredentials())) // make a flag for this?
 		cc, err := grpc.Dial(m.Node.GRPC.RemoteAddr, clientOpts...)
 		if err != nil {
 			return nil, errcode.TODO.Wrap(err)
@@ -312,11 +316,25 @@ func (m *Manager) GetAccountStorageKey() ([]byte, error) {
 	return accountutils.GetOrCreateStorageKeyForAccount(m.nativeKeystore, m.accountID)
 }
 
-func (m *Manager) GetAccountStorageSalt() ([]byte, error) {
+func (m *Manager) GetAccountMessengerDBSalt() ([]byte, error) {
 	if m.nativeKeystore == nil {
 		return nil, nil
 	}
-	return accountutils.GetOrCreateStorageSaltForAccount(m.nativeKeystore, m.accountID)
+	return accountutils.GetOrCreateMessengerDBSaltForAccount(m.nativeKeystore, m.accountID)
+}
+
+func (m *Manager) GetAccountIPFSDatastoreSalt() ([]byte, error) {
+	if m.nativeKeystore == nil {
+		return nil, nil
+	}
+	return accountutils.GetOrCreateIPFSDatastoreSaltForAccount(m.nativeKeystore, m.accountID)
+}
+
+func (m *Manager) GetAccountRootDatastoreSalt() ([]byte, error) {
+	if m.nativeKeystore == nil {
+		return nil, nil
+	}
+	return accountutils.GetOrCreateRootDatastoreSaltForAccount(m.nativeKeystore, m.accountID)
 }
 
 func (m *Manager) SetLifecycleManager(manager *lifecycle.Manager) {
@@ -343,7 +361,7 @@ func (m *Manager) getLifecycleManager() *lifecycle.Manager {
 		return m.Node.Messenger.lcmanager
 	}
 
-	m.Node.Messenger.lcmanager = lifecycle.NewManager(bertymessenger.StateActive)
+	m.Node.Messenger.lcmanager = lifecycle.NewManager(lifecycle.StateActive)
 	return m.Node.Messenger.lcmanager
 }
 
@@ -444,7 +462,7 @@ func (m *Manager) getMessengerDB() (*gorm.DB, error) {
 		return nil, errcode.TODO.Wrap(err)
 	}
 
-	dir, err := m.getDatastoreDir()
+	dir, err := m.getSharedDataDir()
 	if err != nil {
 		return nil, errcode.TODO.Wrap(err)
 	}
@@ -454,7 +472,12 @@ func (m *Manager) getMessengerDB() (*gorm.DB, error) {
 		return nil, errcode.TODO.Wrap(err)
 	}
 
-	m.Node.Messenger.db, m.Node.Messenger.dbCleanup, err = accountutils.GetMessengerDBForPath(dir, key, logger)
+	salt, err := m.GetAccountMessengerDBSalt()
+	if err != nil {
+		return nil, errcode.TODO.Wrap(err)
+	}
+
+	m.Node.Messenger.db, m.Node.Messenger.dbCleanup, err = accountutils.GetMessengerDBForPath(dir, key, salt, logger)
 	if err != nil {
 		return nil, errcode.TODO.Wrap(err)
 	}
@@ -478,7 +501,7 @@ func (m *Manager) getReplicationDB() (*gorm.DB, error) {
 		return nil, errcode.TODO.Wrap(err)
 	}
 
-	dir, err := m.getDatastoreDir()
+	dir, err := m.getAppDataDir()
 	if err != nil {
 		return nil, errcode.TODO.Wrap(err)
 	}
@@ -551,6 +574,12 @@ func (m *Manager) getLocalMessengerServer() (messengertypes.MessengerServiceServ
 		return nil, errcode.TODO.Wrap(fmt.Errorf("unable to init logger: %w", err))
 	}
 
+	// log file path
+	currentLogfilePath := ""
+	if currentLogfilePath, err = logutil.CurrentLogfilePath(m.Logging.FilePath); err != nil {
+		logger.Warn("failed to get the current log file from path", zap.String("path", m.Logging.FilePath))
+	}
+
 	// messenger db
 	db, err := m.getMessengerDB()
 	if err != nil {
@@ -608,6 +637,7 @@ func (m *Manager) getLocalMessengerServer() (messengertypes.MessengerServiceServ
 		StateBackup:         m.Node.Messenger.localDBState,
 		Ring:                m.Logging.ring,
 		PlatformPushToken:   pushPlatformToken,
+		LogFilePath:         currentLogfilePath,
 	}
 	messengerServer, err := bertymessenger.New(protocolClient, &opts)
 	if err != nil {
@@ -620,6 +650,15 @@ func (m *Manager) getLocalMessengerServer() (messengertypes.MessengerServiceServ
 		return nil, errcode.TODO.Wrap(fmt.Errorf("unable to register messenger service handler: %w", err))
 	}
 
+	// Auto attach to Tyber hosts
+	if m.Logging.TyberAutoAttach != "" {
+		if _, err := messengerServer.TyberHostAttach(m.ctx, &messengertypes.TyberHostAttach_Request{
+			Addresses: strings.Split(m.Logging.TyberAutoAttach, ","),
+		}); err != nil {
+			m.initLogger.Error("messenger server cannot attach to tyber host", zap.Error(err))
+		}
+	}
+
 	m.Node.Messenger.lcmanager = lcmanager
 	m.Node.Messenger.server = messengerServer
 	m.initLogger.Debug("messenger server initialized and cached")
