@@ -5,7 +5,7 @@ import (
 
 	datastore "github.com/ipfs/go-datastore"
 	keystore "github.com/ipfs/go-ipfs-keystore"
-	"github.com/libp2p/go-libp2p-core/crypto"
+	"github.com/libp2p/go-libp2p/core/crypto"
 
 	"berty.tech/berty/v2/go/pkg/errcode"
 )
