@@ -7,11 +7,11 @@ import (
 	"time"
 
 	ipfs_ds "github.com/ipfs/go-datastore"
-	ipfs_cfg "github.com/ipfs/go-ipfs-config"
-	ipfs_loader "github.com/ipfs/go-ipfs/plugin/loader"
-	ipfs_repo "github.com/ipfs/go-ipfs/repo"
-	p2p_ci "github.com/libp2p/go-libp2p-core/crypto"
-	p2p_peer "github.com/libp2p/go-libp2p-core/peer"
+	ipfs_cfg "github.com/ipfs/kubo/config"
+	ipfs_loader "github.com/ipfs/kubo/plugin/loader"
+	ipfs_repo "github.com/ipfs/kubo/repo"
+	p2p_ci "github.com/libp2p/go-libp2p/core/crypto"
+	p2p_peer "github.com/libp2p/go-libp2p/core/peer"
 	"github.com/pkg/errors"
 
 	"berty.tech/berty/v2/go/pkg/errcode"
@@ -52,7 +52,8 @@ func LoadRepoFromPath(path string, key []byte, salt []byte) (ipfs_repo.Repo, err
 	}
 
 	// init repo if needed
-	isInit, err := encrepo.IsInitialized(path, key, salt)
+	sqldsOpts := encrepo.SQLCipherDatastoreOptions{JournalMode: "WAL", PlaintextHeader: len(salt) != 0, Salt: salt}
+	isInit, err := encrepo.IsInitialized(path, key, sqldsOpts)
 	if err != nil {
 		return nil, errors.Wrap(err, "failed to check if repo is initialized")
 	}
@@ -69,12 +70,12 @@ func LoadRepoFromPath(path string, key []byte, salt []byte) (ipfs_repo.Repo, err
 
 		ucfg.Datastore.Spec = nil
 
-		if err := encrepo.Init(path, key, salt, ucfg); err != nil {
+		if err := encrepo.Init(path, key, sqldsOpts, ucfg); err != nil {
 			return nil, errors.Wrap(err, "failed to init repo")
 		}
 	}
 
-	return encrepo.Open(path, key, salt)
+	return encrepo.Open(path, key, sqldsOpts)
 }
 
 var DefaultSwarmListeners = []string{
@@ -96,7 +97,6 @@ func createBaseConfig() (*ipfs_cfg.Config, error) {
 
 	// Discovery
 	c.Discovery.MDNS.Enabled = true
-	c.Discovery.MDNS.Interval = 5
 
 	// swarm listeners
 	c.Addresses.Swarm = DefaultSwarmListeners
@@ -139,7 +139,8 @@ func ResetExistingRepoIdentity(repo ipfs_repo.Repo, path string, key []byte, sal
 		return nil, errcode.ErrInternal.Wrap(err)
 	}
 
-	repo, err = encrepo.Open(path, key, salt)
+	sqldsOpts := encrepo.SQLCipherDatastoreOptions{JournalMode: "WAL", PlaintextHeader: len(salt) != 0, Salt: salt}
+	repo, err = encrepo.Open(path, key, sqldsOpts)
 	if err != nil {
 		return nil, errcode.ErrInternal.Wrap(err)
 	}
