@@ -7,31 +7,29 @@ import (
 	"fmt"
 	"math/rand"
 	"testing"
-	"time"
 
-	ipfs_mobile "github.com/ipfs-shipyard/gomobile-ipfs/go/pkg/ipfsmobile"
+	rendezvous "github.com/berty/go-libp2p-rendezvous"
+	p2p_rpdb "github.com/berty/go-libp2p-rendezvous/db/sqlcipher"
 	ds "github.com/ipfs/go-datastore"
 	dsync "github.com/ipfs/go-datastore/sync"
-	ipfs_cfg "github.com/ipfs/go-ipfs-config"
-	ipfs_core "github.com/ipfs/go-ipfs/core"
-	ipfs_mock "github.com/ipfs/go-ipfs/core/mock"
-	ipfs_repo "github.com/ipfs/go-ipfs/repo"
-	p2p_ci "github.com/libp2p/go-libp2p-core/crypto"
-	host "github.com/libp2p/go-libp2p-core/host"
-	p2pnetwork "github.com/libp2p/go-libp2p-core/network"
-	p2p_peer "github.com/libp2p/go-libp2p-core/peer"
-	"github.com/libp2p/go-libp2p-core/peerstore"
-	"github.com/libp2p/go-libp2p-core/protocol"
-	"github.com/libp2p/go-libp2p-core/routing"
-	discovery "github.com/libp2p/go-libp2p-discovery"
+	ipfs_cfg "github.com/ipfs/kubo/config"
+	ipfs_core "github.com/ipfs/kubo/core"
+	ipfs_mock "github.com/ipfs/kubo/core/mock"
+	ipfs_repo "github.com/ipfs/kubo/repo"
 	pubsub "github.com/libp2p/go-libp2p-pubsub"
-	rendezvous "github.com/libp2p/go-libp2p-rendezvous"
-	p2p_rpdb "github.com/libp2p/go-libp2p-rendezvous/db/sqlcipher"
+	p2p_ci "github.com/libp2p/go-libp2p/core/crypto"
+	host "github.com/libp2p/go-libp2p/core/host"
+	p2pnetwork "github.com/libp2p/go-libp2p/core/network"
+	p2p_peer "github.com/libp2p/go-libp2p/core/peer"
+	"github.com/libp2p/go-libp2p/core/peerstore"
+	"github.com/libp2p/go-libp2p/core/protocol"
+	"github.com/libp2p/go-libp2p/core/routing"
 	p2p_mocknet "github.com/libp2p/go-libp2p/p2p/net/mock"
 	"github.com/stretchr/testify/require"
 	"go.uber.org/zap"
 
-	"berty.tech/berty/v2/go/internal/tinder"
+	ipfs_mobile "berty.tech/berty/v2/go/internal/ipfsutil/mobile"
+	tinder "berty.tech/berty/v2/go/internal/tinder"
 )
 
 // CoreAPIMock implements ipfs.CoreAPI and adds some debugging helpers
@@ -39,7 +37,7 @@ type CoreAPIMock interface {
 	API() ExtendedCoreAPI
 
 	PubSub() *pubsub.PubSub
-	Tinder() tinder.Service
+	Tinder() *tinder.Service
 	MockNetwork() p2p_mocknet.Mocknet
 	MockNode() *ipfs_core.IpfsNode
 	Close()
@@ -130,55 +128,36 @@ func TestingCoreAPIUsingMockNet(ctx context.Context, t testing.TB, opts *Testing
 	repo := TestingRepo(t, ctx, datastore)
 
 	var ps *pubsub.PubSub
-	var disc tinder.Service
+	var stinder *tinder.Service
+	var discAdaptater *tinder.DiscoveryAdaptater
+
 	configureRouting := func(h host.Host, r routing.Routing) error {
 		var err error
-		drivers := []*tinder.Driver{}
+		drivers := []tinder.IDriver{}
 		if opts.RDVPeer.ID != "" {
-			// opts.Mocknet.ConnectPeers(node.Identity, opts.RDVPeer.ID)
 			h.Peerstore().AddAddrs(opts.RDVPeer.ID, opts.RDVPeer.Addrs, peerstore.PermanentAddrTTL)
-			// @FIXME(gfanton): use rand as argument
-			rdvp := tinder.NewRendezvousDiscovery(opts.Logger, h, opts.RDVPeer.ID, rand.New(rand.NewSource(rand.Int63())))
+			cl := rendezvous.NewSyncInMemClient(ctx, h)
+			ms := tinder.NewRendezvousDiscovery(opts.Logger.Named("rdvp"), h, opts.RDVPeer.ID, rand.New(rand.NewSource(rand.Int63())), cl)
 			if _, err = opts.Mocknet.LinkPeers(h.ID(), opts.RDVPeer.ID); err != nil {
 				return err
 			}
 
-			driver := tinder.NewDriverFromUnregisterDiscovery("rdpv", rdvp, nil)
-			drivers = append(drivers, driver)
+			drivers = append(drivers, ms)
 		}
 
 		if r != nil {
-			driver := tinder.NewDriverFromRouting("dht", r, nil)
+			driver := tinder.NewRoutingDiscoveryDriver("dht", r)
 			drivers = append(drivers, driver)
 		}
 
-		// minBackoff, maxBackoff := time.Second, time.Minute
-		// rng := rand.New(rand.NewSource(rand.Int63()))
-		tinderOpts := &tinder.Opts{
-			Logger:                 opts.Logger,
-			AdvertiseResetInterval: time.Minute,
-			AdvertiseGracePeriod:   time.Minute,
-			BackoffStrategy: &tinder.BackoffOpts{
-				StratFactory: discovery.NewFixedBackoff(time.Second),
-			},
-			// BackoffStratFactory: discovery.NewExponentialBackoff(minBackoff, maxBackoff, discovery.FullJitter, time.Second, 5.0, 0, rng),
-		}
-
 		// enable discovery monitor
-		disc, err = tinder.NewService(tinderOpts, h, drivers...)
+		stinder, err = tinder.NewService(h, opts.Logger, drivers...)
 		if err != nil {
 			return fmt.Errorf("unable to monitor discovery driver: %w", err)
 		}
 
-		pubsubtracker, err := NewPubsubMonitor(opts.Logger, h)
-		if err != nil {
-			return err
-		}
-
-		ps, err = pubsub.NewGossipSub(ctx, h,
-			pubsub.WithDiscovery(disc),
-			pubsubtracker.EventTracerOption(),
-		)
+		discAdaptater = tinder.NewDiscoveryAdaptater(opts.Logger, stinder)
+		ps, err = pubsub.NewGossipSub(ctx, h, pubsub.WithDiscovery(discAdaptater))
 
 		return err
 	}
@@ -194,12 +173,12 @@ func TestingCoreAPIUsingMockNet(ctx context.Context, t testing.TB, opts *Testing
 
 	require.NoError(t, err, "failed to initialize IPFS node mock")
 	require.NotNil(t, ps, "pubsub should not be nil")
-	require.NotNil(t, disc, "discovery should not be nil")
+	require.NotNil(t, stinder, "discovery should not be nil")
 
 	exapi, err := NewExtendedCoreAPIFromNode(mnode.IpfsNode)
 	require.NoError(t, err, "unable to extend core api from node")
 
-	psapi := NewPubSubAPI(ctx, opts.Logger, disc, ps)
+	psapi := NewPubSubAPI(ctx, opts.Logger, ps)
 	exapi = InjectPubSubCoreAPIExtendedAdapter(exapi, psapi)
 	EnableConnLogger(ctx, opts.Logger, mnode.PeerHost())
 
@@ -208,10 +187,14 @@ func TestingCoreAPIUsingMockNet(ctx context.Context, t testing.TB, opts *Testing
 		mocknet: opts.Mocknet,
 		pubsub:  ps,
 		node:    mnode.IpfsNode,
-		tinder:  disc,
+		tinder:  stinder,
 	}
 
 	return api, func() {
+		if discAdaptater != nil {
+			discAdaptater.Close()
+		}
+
 		_ = mnode.Close()
 		_ = mnode.PeerHost().Close()
 		_ = repo.Close()
@@ -224,7 +207,9 @@ func TestingCoreAPIUsingMockNet(ctx context.Context, t testing.TB, opts *Testing
 func TestingCoreAPI(ctx context.Context, t testing.TB) (CoreAPIMock, func()) {
 	t.Helper()
 
-	m := p2p_mocknet.New(ctx)
+	m := p2p_mocknet.New()
+	defer m.Close()
+
 	rdvPeer, err := m.GenPeer()
 	require.NoError(t, err)
 
@@ -246,7 +231,10 @@ func TestingRDVP(ctx context.Context, t testing.TB, h host.Host) (*rendezvous.Re
 	db, err := p2p_rpdb.OpenDB(ctx, ":memory:")
 	require.NoError(t, err)
 
-	svc := rendezvous.NewRendezvousService(h, db)
+	provider, err := rendezvous.NewSyncInMemProvider(h)
+	require.NoError(t, err)
+
+	svc := rendezvous.NewRendezvousService(h, db, provider)
 	cleanup := func() {
 		_ = db.Close() // dont use me for now as db is open in_memory
 	}
@@ -259,7 +247,7 @@ type coreAPIMock struct {
 	pubsub  *pubsub.PubSub
 	mocknet p2p_mocknet.Mocknet
 	node    *ipfs_core.IpfsNode
-	tinder  tinder.Service
+	tinder  *tinder.Service
 }
 
 func (m *coreAPIMock) ConnMgr() ConnMgr {
@@ -294,11 +282,10 @@ func (m *coreAPIMock) PubSub() *pubsub.PubSub {
 	return m.pubsub
 }
 
-func (m *coreAPIMock) Tinder() tinder.Service {
+func (m *coreAPIMock) Tinder() *tinder.Service {
 	return m.tinder
 }
 
 func (m *coreAPIMock) Close() {
 	m.node.Close()
-	m.tinder.Close()
 }
