@@ -104,8 +104,6 @@ func (h *EventHandler) bindHandlers() {
 		mt.AppMessage_TypeGroupInvitation: {h.handleAppMessageGroupInvitation, true},
 		mt.AppMessage_TypeUserMessage:     {h.handleAppMessageUserMessage, true},
 		mt.AppMessage_TypeSetUserInfo:     {h.handleAppMessageSetUserInfo, false},
-		mt.AppMessage_TypeReplyOptions:    {h.handleAppMessageReplyOptions, false},
-		mt.AppMessage_TypeUserReaction:    {h.handleAppMessageUserReaction, false},
 		mt.AppMessage_TypeSetGroupInfo:    {h.handleAppMessageSetGroupInfo, false},
 	}
 }
@@ -173,7 +171,6 @@ func (h *EventHandler) HandleAppMessage(gpk string, gme *protocoltypes.GroupMess
 	muts := []tyber.StepMutator{
 		tyber.WithDetail("Type", am.GetType().String()),
 		tyber.WithCIDDetail("CID", gme.GetEventContext().GetID()),
-		tyber.WithDetail("MediasCount", strconv.Itoa(len(am.GetMedias()))),
 		tyber.WithDetail("TargetCID", am.GetTargetCID()),
 		tyber.WithDetail("LocalMemberPK", messengerutil.B64EncodeBytes(memPK)),
 		tyber.WithDetail("LocalDevicePK", messengerutil.B64EncodeBytes(devPK)),
@@ -193,16 +190,9 @@ func (h *EventHandler) HandleAppMessage(gpk string, gme *protocoltypes.GroupMess
 	}
 	tyber.LogStep(h.ctx, h.logger, "Generated interaction", tyber.WithJSONDetail("Interaction", i))
 
-	medias := i.GetMedias()
-	var mediasAdded []bool
-
 	// start a transaction
 	var isNew bool
 	if err := h.db.TX(h.ctx, func(tx *messengerdb.DBWrapper) error {
-		if mediasAdded, err = tx.AddMedias(medias); err != nil {
-			return logError("Failed to add medias", err)
-		}
-
 		interactionFetchRelations(tx, i, h.logger)
 
 		h.logger.Debug("Will handle app message", zap.Any("interaction", i), zap.Any("payload", amPayload))
@@ -236,14 +226,6 @@ func (h *EventHandler) HandleAppMessage(gpk string, gme *protocoltypes.GroupMess
 		}
 	}
 
-	for i, media := range medias {
-		if mediasAdded[i] {
-			if err := h.dispatcher.StreamEvent(mt.StreamEvent_TypeMediaUpdated, &mt.StreamEvent_MediaUpdated{Media: media}, true); err != nil {
-				h.logger.Error("Unable to dispatch notification for media", tyber.FormatStepLogFields(h.ctx, tyber.ZapFieldsToDetails(logutil.PrivateString("cid", media.CID), zap.Error(err)))...)
-			}
-		}
-	}
-
 	return nil
 }
 
@@ -810,7 +792,6 @@ func (h *EventHandler) groupMemberDeviceAdded(gme *protocoltypes.GroupMetadataEv
 	}
 	if userInfo != nil {
 		member.DisplayName = userInfo.GetDisplayName()
-		member.AvatarCID = userInfo.GetAvatarCID()
 	}
 
 	member, isNew, err := h.db.UpsertMember(mpk, gpk, *member)
@@ -897,7 +878,6 @@ func (h *EventHandler) handleAppMessageGroupInvitation(tx *messengerdb.DBWrapper
 
 func (h *EventHandler) handleAppMessageUserMessage(tx *messengerdb.DBWrapper, i *mt.Interaction, amPayload proto.Message) (*mt.Interaction, bool, error) {
 	// NOTE: it's ok to have an empty payload here since a user message can be only medias
-
 	i, isNew, err := tx.AddInteraction(*i)
 	if err != nil {
 		return nil, isNew, err
@@ -978,8 +958,7 @@ func (h *EventHandler) handleAppMessageSetUserInfo(tx *messengerdb.DBWrapper, i
 		h.logger.Debug("interesting contact SetUserInfo")
 
 		c.DisplayName = payload.GetDisplayName()
-		c.AvatarCID = payload.GetAvatarCID()
-		err = tx.UpdateContact(cpk, mt.Contact{DisplayName: c.GetDisplayName(), AvatarCID: c.GetAvatarCID(), InfoDate: i.GetSentDate()})
+		err = tx.UpdateContact(cpk, mt.Contact{DisplayName: c.GetDisplayName(), InfoDate: i.GetSentDate()})
 		if err != nil {
 			return nil, false, err
 		}
@@ -1023,7 +1002,7 @@ func (h *EventHandler) handleAppMessageSetUserInfo(tx *messengerdb.DBWrapper, i
 	member, isNew, err := tx.UpsertMember(
 		i.MemberPublicKey,
 		i.ConversationPublicKey,
-		mt.Member{DisplayName: payload.GetDisplayName(), AvatarCID: payload.GetAvatarCID(), InfoDate: i.GetSentDate()},
+		mt.Member{DisplayName: payload.GetDisplayName(), InfoDate: i.GetSentDate()},
 	)
 	if err != nil {
 		return nil, false, err
@@ -1039,43 +1018,6 @@ func (h *EventHandler) handleAppMessageSetUserInfo(tx *messengerdb.DBWrapper, i
 	return i, false, nil
 }
 
-func (h *EventHandler) handleAppMessageUserReaction(tx *messengerdb.DBWrapper, i *mt.Interaction, amPayload proto.Message) (*mt.Interaction, bool, error) {
-	if len(i.GetPayload()) == 0 {
-		return nil, false, ErrNilPayload
-	}
-
-	return i, false, h.handleReaction(tx, i, amPayload)
-}
-
-func (h *EventHandler) handleReaction(tx *messengerdb.DBWrapper, i *mt.Interaction, amPayload proto.Message) error {
-	if len(i.MemberPublicKey) == 0 {
-		return errcode.ErrInvalidInput.Wrap(errors.New("empty member public key"))
-	}
-	if len(i.TargetCID) == 0 {
-		return errcode.ErrInvalidInput.Wrap(errors.New("empty target cid"))
-	}
-
-	updated, err := tx.CreateOrUpdateReaction(&mt.Reaction{
-		TargetCID:       i.TargetCID,
-		MemberPublicKey: i.MemberPublicKey,
-		Emoji:           amPayload.(interface{ GetEmoji() string }).GetEmoji(),
-		IsMine:          i.IsMine,
-		State:           amPayload.(interface{ GetState() bool }).GetState(),
-		StateDate:       i.GetSentDate(),
-	})
-	if err != nil {
-		return errcode.ErrDBRead.Wrap(err)
-	}
-
-	if updated {
-		if err := messengerutil.StreamInteraction(h.dispatcher, tx, i.TargetCID, false); err != nil {
-			h.logger.Debug("failed to stream updated target interaction after AddReaction", zap.Error(err))
-		}
-	}
-
-	return nil
-}
-
 func interactionFromAppMessage(h *EventHandler, gpk string, gme *protocoltypes.GroupMessageEvent, am *mt.AppMessage) (*mt.Interaction, error) {
 	amt := am.GetType()
 	cid, err := ipfscid.Cast(gme.GetEventContext().GetID())
@@ -1115,16 +1057,10 @@ func interactionFromAppMessage(h *EventHandler, gpk string, gme *protocoltypes.G
 		ConversationPublicKey: gpk,
 		SentDate:              am.GetSentDate(),
 		DevicePublicKey:       dpk,
-		Medias:                am.GetMedias(),
 		MemberPublicKey:       mpk,
 		TargetCID:             am.GetTargetCID(),
 	}
 
-	for _, media := range i.Medias {
-		media.InteractionCID = i.CID
-		media.State = mt.Media_StateNeverDownloaded
-	}
-
 	return &i, nil
 }
 
@@ -1221,23 +1157,6 @@ func interactionConsumeAck(tx *messengerdb.DBWrapper, i *mt.Interaction, dispatc
 	return nil
 }
 
-func (h *EventHandler) handleAppMessageReplyOptions(tx *messengerdb.DBWrapper, i *mt.Interaction, _ proto.Message) (*mt.Interaction, bool, error) {
-	if len(i.GetPayload()) == 0 {
-		return nil, false, ErrNilPayload
-	}
-
-	i, isNew, err := tx.AddInteraction(*i)
-	if err != nil {
-		return nil, isNew, err
-	}
-
-	if err := messengerutil.StreamInteraction(h.dispatcher, tx, i.CID, isNew); err != nil {
-		return nil, isNew, err
-	}
-
-	return i, isNew, nil
-}
-
 func indexMessage(tx *messengerdb.DBWrapper, id string, am *mt.AppMessage) error {
 	if len(id) == 0 {
 		return nil
@@ -1281,12 +1200,9 @@ func (h *EventHandler) handleAppMessageSetGroupInfo(tx *messengerdb.DBWrapper, i
 		if payload.GetDisplayName() != "" {
 			c.DisplayName = payload.GetDisplayName()
 		}
-		if payload.GetAvatarCid() != "" {
-			c.AvatarCID = payload.GetAvatarCid()
-		}
 		c.InfoDate = i.GetSentDate()
 
-		_, err = tx.UpdateConversation(mt.Conversation{DisplayName: c.GetDisplayName(), AvatarCID: c.GetAvatarCID(), InfoDate: c.GetInfoDate(), PublicKey: c.GetPublicKey()})
+		_, err = tx.UpdateConversation(mt.Conversation{DisplayName: c.GetDisplayName(), InfoDate: c.GetInfoDate(), PublicKey: c.GetPublicKey()})
 		if err != nil {
 			return nil, false, err
 		}
@@ -1323,7 +1239,7 @@ func interactionFromOutOfStoreAppMessage(h *EventHandler, gPKBytes []byte, outOf
 
 	dpk := messengerutil.B64EncodeBytes(outOfStoreMessage.DevicePK)
 
-	h.logger.Debug("received app message", logutil.PrivateString("type", amt.String()), zap.Int("numMedias", len(am.GetMedias())))
+	h.logger.Debug("received app message", logutil.PrivateString("type", amt.String()))
 
 	mpk := ""
 	dev, err := h.db.GetDeviceByPK(dpk)
@@ -1342,15 +1258,9 @@ func interactionFromOutOfStoreAppMessage(h *EventHandler, gPKBytes []byte, outOf
 		SentDate:              am.GetSentDate(),
 		DevicePublicKey:       dpk,
 		MemberPublicKey:       mpk,
-		Medias:                am.GetMedias(),
 		OutOfStoreMessage:     true,
 	}
 
-	for _, media := range i.Medias {
-		media.InteractionCID = i.CID
-		media.State = mt.Media_StateNeverDownloaded
-	}
-
 	return &i, nil
 }
 
