@@ -5,7 +5,7 @@ import (
 	"sync"
 	"testing"
 
-	"github.com/libp2p/go-libp2p-core/crypto"
+	"github.com/libp2p/go-libp2p/core/crypto"
 	"github.com/stretchr/testify/require"
 
 	"berty.tech/berty/v2/go/pkg/protocoltypes"
