@@ -35,7 +35,12 @@ func (s *service) getGroupForPK(ctx context.Context, pk crypto.PubKey) (*protoco
 		return nil, errcode.ErrInternal.Wrap(err)
 	}
 
-	if err = reindexGroupDatastore(ctx, s.groupDatastore, s.accountGroup.metadataStore, s.deviceKeystore); err != nil {
+	accountGroup := s.getAccountGroup()
+	if accountGroup == nil {
+		return nil, errcode.ErrGroupMissing
+	}
+
+	if err = reindexGroupDatastore(ctx, s.groupDatastore, accountGroup.metadataStore, s.deviceKeystore); err != nil {
 		return nil, errcode.TODO.Wrap(err)
 	}
 
@@ -61,11 +66,6 @@ func (s *service) deactivateGroup(pk crypto.PubKey) error {
 		return nil
 	}
 
-	if cg.group.GroupType == protocoltypes.GroupTypeAccount {
-		// @FIXME(gfanton): do not close manually close berty account for now
-		return errcode.ErrBertyAccount.Wrap(fmt.Errorf("cannot manually deactivate berty account"))
-	}
-
 	s.lock.Lock()
 	defer s.lock.Unlock()
 
@@ -76,20 +76,11 @@ func (s *service) deactivateGroup(pk crypto.PubKey) error {
 
 	delete(s.openedGroups, string(id))
 
-	return nil
-}
-
-func (s *service) closeBertyAccount() error {
-	s.lock.Lock()
-	defer s.lock.Unlock()
-
-	err := s.accountGroup.Close()
-	if err != nil {
-		s.logger.Error("unable to close acount group", zap.Error(err))
+	if cg.group.GroupType == protocoltypes.GroupTypeAccount {
+		s.accountGroup = nil
 	}
 
-	delete(s.openedGroups, s.accountGroup.Group().GroupIDAsString())
-	return err
+	return nil
 }
 
 func (s *service) activateGroup(ctx context.Context, pk crypto.PubKey, localOnly bool) error {
@@ -98,9 +89,9 @@ func (s *service) activateGroup(ctx context.Context, pk crypto.PubKey, localOnly
 		return errcode.ErrSerialization.Wrap(err)
 	}
 
-	cg, err := s.GetContextGroupForID(id)
-	if err == nil && cg != nil {
-		return nil
+	_, err = s.GetContextGroupForID(id)
+	if err != nil && err != errcode.ErrGroupUnknown {
+		return err
 	}
 
 	g, err := s.getGroupForPK(ctx, pk)
@@ -117,6 +108,10 @@ func (s *service) activateGroup(ctx context.Context, pk crypto.PubKey, localOnly
 		// nothing to get here, simply continue, open and activate the group
 
 	case protocoltypes.GroupTypeContact:
+		if s.accountGroup == nil {
+			return errcode.ErrGroupActivate.Wrap(fmt.Errorf("accountGroup is deactivated"))
+		}
+
 		contact := s.accountGroup.metadataStore.GetContactFromGroupPK(id)
 		if contact != nil {
 			contactPK, err = contact.GetPubKey()
@@ -125,24 +120,39 @@ func (s *service) activateGroup(ctx context.Context, pk crypto.PubKey, localOnly
 			}
 		}
 	case protocoltypes.GroupTypeAccount:
-		return errcode.ErrBertyAccountAlreadyOpened
+		localOnly = true
+		if s.accountGroup, err = s.odb.openAccountGroup(ctx, &iface.CreateDBOptions{EventBus: s.accountEventBus, LocalOnly: &localOnly}, s.ipfsCoreAPI); err != nil {
+			return err
+		}
+		s.openedGroups[string(id)] = s.accountGroup
+
+		// reinitialize contactRequestsManager
+		if s.contactRequestsManager != nil {
+			s.contactRequestsManager.close()
+
+			if s.contactRequestsManager, err = newContactRequestsManager(s.swiper, s.accountGroup.metadataStore, s.ipfsCoreAPI, s.logger); err != nil {
+				return errcode.TODO.Wrap(err)
+			}
+		}
+		return nil
 	default:
 		return errcode.ErrInternal.Wrap(fmt.Errorf("unknown group type"))
 	}
 
 	dbOpts := &iface.CreateDBOptions{LocalOnly: &localOnly}
-	gc, err := s.odb.OpenGroup(g, dbOpts)
+	gc, err := s.odb.OpenGroup(ctx, g, dbOpts)
 	if err != nil {
 		return errcode.ErrBertyAccountOpenAccount.Wrap(err)
 	}
 
-	if err := ActivateGroupContext(s.ctx, gc, contactPK); err != nil {
+	if err := gc.ActivateGroupContext(contactPK); err != nil {
+		gc.Close()
 		return errcode.ErrGroupActivate.Wrap(err)
 	}
 
 	s.openedGroups[string(id)] = gc
 
-	TagGroupContextPeers(s.ctx, s.logger, gc, s.ipfsCoreAPI, 42)
+	gc.TagGroupContextPeers(s.ipfsCoreAPI, 42)
 	return nil
 }
 
@@ -160,7 +170,7 @@ func (s *service) GetContextGroupForID(id []byte) (*GroupContext, error) {
 		return cg, nil
 	}
 
-	return nil, errcode.ErrInternal.Wrap(fmt.Errorf("unknown group or not activated yet"))
+	return nil, errcode.ErrGroupUnknown
 }
 
 func reindexGroupDatastore(ctx context.Context, gd *cryptoutil.GroupDatastore, m *MetadataStore, deviceKeystore cryptoutil.DeviceKeystore) error {
@@ -194,3 +204,9 @@ func reindexGroupDatastore(ctx context.Context, gd *cryptoutil.GroupDatastore, m
 
 	return nil
 }
+
+func (s *service) getAccountGroup() *GroupContext {
+	s.lock.Lock()
+	defer s.lock.Unlock()
+	return s.accountGroup
+}
