@@ -7,7 +7,7 @@ import (
 	"sync"
 
 	"github.com/gogo/protobuf/proto"
-	"github.com/libp2p/go-libp2p-core/crypto"
+	"github.com/libp2p/go-libp2p/core/crypto"
 	"go.uber.org/zap"
 
 	"berty.tech/berty/v2/go/internal/cryptoutil"
@@ -88,7 +88,7 @@ func (m *metadataStoreIndex) UpdateIndex(log ipfslog.Log, _ []ipfslog.Entry) err
 			continue
 		}
 
-		metaEvent, event, err := openMetadataEntry(log, e, m.g, m.deviceKeystore)
+		metaEvent, event, err := openMetadataEntry(log, e, m.g)
 		if err != nil {
 			m.logger.Error("unable to open metadata entry", zap.Error(err))
 			continue
