@@ -6,7 +6,6 @@ import (
 	"testing"
 	"time"
 
-	"github.com/libp2p/go-libp2p-core/peer"
 	p2pmocknet "github.com/libp2p/go-libp2p/p2p/net/mock"
 	"github.com/stretchr/testify/assert"
 	"github.com/stretchr/testify/require"
@@ -48,7 +47,7 @@ func TestAnnounceWatchForPeriod(t *testing.T) {
 			ctx, cancel := context.WithCancel(context.Background())
 			defer cancel()
 
-			mn := p2pmocknet.New(ctx)
+			mn := p2pmocknet.New()
 			rdvp, err := mn.GenPeer()
 			require.NoError(t, err, "failed to generate mocked peer")
 
@@ -84,22 +83,19 @@ func TestAnnounceWatchForPeriod(t *testing.T) {
 
 			time.Sleep(time.Millisecond * 100)
 
-			ch := make(chan peer.AddrInfo)
-			doneFn := func() {}
-			go swiperB.WatchTopic(ctx, tc.topicB, tc.seedB, ch, doneFn)
+			cpeers := swiperB.WatchTopic(ctx, tc.topicB, tc.seedB)
 
 			var foundPeers int
-
 		loop:
 			for foundPeers = 0; foundPeers < tc.expectedPeersFound; foundPeers++ {
 				select {
 				case <-ctx.Done():
 					break loop
-				case <-ch:
+				case <-cpeers:
 				}
 			}
 
-			assert.Equal(t, len(ch), 0)
+			assert.Equal(t, len(cpeers), 0)
 			assert.Equal(t, tc.expectedPeersFound, foundPeers)
 		})
 	}
