@@ -7,7 +7,6 @@ import com.facebook.react.ReactActivity;
 import com.zoontek.rnbootsplash.RNBootSplash; // needed by react-native-bootsplash
 import com.facebook.react.ReactActivityDelegate;
 import com.facebook.react.ReactRootView;
-import com.swmansion.gesturehandler.react.RNGestureHandlerEnabledRootView;
 
 import android.util.Log;
 import android.view.MotionEvent;
@@ -34,18 +33,6 @@ public class MainActivity extends ReactActivity implements LifecycleObserver {
         return "Berty";
     }
 
-    @Override
-    protected ReactActivityDelegate createReactActivityDelegate() {
-        return new ReactActivityDelegateWrapper(this,
-            new ReactActivityDelegate(this, getMainComponentName()) {
-                @Override
-                protected ReactRootView createRootView() {
-                    return new RNGestureHandlerEnabledRootView(MainActivity.this);
-                }
-            }
-        );
-    }
-
     public static AppState getAppState() {
         return MainActivity.appState;
     }
