@@ -3,8 +3,6 @@
  */
 
 import 'node-libs-react-native/globals'
-import 'react-native-gesture-handler'
-import 'react-native-reanimated'
 import 'string.fromcodepoint'
 
 import protobuf from 'protobufjs'
