@@ -4,7 +4,7 @@ const uncap = str => str.slice(0, 1).toLowerCase() + str.slice(1)
 
 console.log("import beapi from '@berty/api'")
 
-console.log("\nimport { UnaryType, RequestStreamType, ResponseStreamType } from './types'")
+console.log("\nimport { UnaryType, ResponseStreamType } from './types'")
 
 const services = [
 	'berty.protocol.v1.ProtocolService',
