@@ -57,18 +57,6 @@ export const useAllContacts = () => {
 	return useAppSelector(m.selectAllContacts)
 }
 
-export const useMedias = (cids: string[]) => {
-	return useAppSelector(state => m.selectMedias(state, cids))
-}
-
-export const useMedia = (cid: string) => {
-	return useAppSelector(state => m.selectMedia(state, cid))
-}
-
-export const useInteractionAuthor = (convPk: string, cid: string) => {
-	return useAppSelector(state => m.selectInteractionAuthor(state, convPk, cid))
-}
-
 export const useMember = (
 	conversationPublicKey: string | null | undefined,
 	publicKey: string | null | undefined,
@@ -170,7 +158,7 @@ export const useReadEffect = (publicKey: Maybe<string>, timeout: Maybe<number>)
 			const { routes } = navigation.getState()
 			for (let route of routes) {
 				if (
-					(route.name === 'Chat.OneToOne' || route.name === 'Chat.Group') &&
+					(route.name === 'Chat.OneToOne' || route.name === 'Chat.MultiMember') &&
 					(route.params as any)?.convId === publicKey
 				) {
 					return
@@ -211,8 +199,8 @@ type Selectors = ObjectSelectors<typeof m>
 type No = ObjectSelectorsToHooks<typeof m>
 
 const getObjectSelectors = <T>(obj: T): ObjectSelectors<T> => {
-	const keys = Object.keys(obj).filter(k => k.startsWith('select'))
-	return keys.reduce((o, k) => ({...o, [k]: (obj as any)[k as any] }), {} as any)
+  const keys = Object.keys(obj).filter(k => k.startsWith('select'))
+  return keys.reduce((o, k) => ({...o, [k]: (obj as any)[k as any] }), {} as any)
 }
 
 const test = getObjectSelectors(m)
