@@ -1,6 +1,6 @@
 import beapi from '@berty/api'
 
-import { UnaryMock, RequestStreamMock, ResponseStreamMock } from './types'
+import { UnaryMock, ResponseStreamMock } from './types'
 
 export interface IProtocolServiceMock {
 	InstanceExportData: ResponseStreamMock<
@@ -97,9 +97,9 @@ export interface IProtocolServiceMock {
 		beapi.protocol.DeactivateGroup.IRequest,
 		beapi.protocol.DeactivateGroup.IReply
 	>
-	MonitorGroup: ResponseStreamMock<
-		beapi.protocol.MonitorGroup.IRequest,
-		beapi.protocol.MonitorGroup.IReply
+	GroupDeviceStatus: ResponseStreamMock<
+		beapi.protocol.GroupDeviceStatus.IRequest,
+		beapi.protocol.GroupDeviceStatus.IReply
 	>
 	DebugListGroups: ResponseStreamMock<
 		beapi.protocol.DebugListGroups.IRequest,
@@ -132,14 +132,6 @@ export interface IProtocolServiceMock {
 		beapi.protocol.ReplicationServiceRegisterGroup.IReply
 	>
 	PeerList: UnaryMock<beapi.protocol.PeerList.IRequest, beapi.protocol.PeerList.IReply>
-	AttachmentPrepare: RequestStreamMock<
-		beapi.protocol.AttachmentPrepare.IRequest,
-		beapi.protocol.AttachmentPrepare.IReply
-	>
-	AttachmentRetrieve: ResponseStreamMock<
-		beapi.protocol.AttachmentRetrieve.IRequest,
-		beapi.protocol.AttachmentRetrieve.IReply
-	>
 	PushReceive: UnaryMock<beapi.protocol.PushReceive.IRequest, beapi.protocol.PushReceive.IReply>
 	PushSend: UnaryMock<beapi.protocol.PushSend.IRequest, beapi.protocol.PushSend.IReply>
 	PushShareToken: UnaryMock<
@@ -185,6 +177,10 @@ export interface IAccountServiceMock {
 		beapi.account.GetGRPCListenerAddrs.IReply
 	>
 	LogfileList: UnaryMock<beapi.account.LogfileList.IRequest, beapi.account.LogfileList.IReply>
+	StreamLogfile: ResponseStreamMock<
+		beapi.account.StreamLogfile.IRequest,
+		beapi.account.StreamLogfile.IReply
+	>
 	GetUsername: UnaryMock<beapi.account.GetUsername.IRequest, beapi.account.GetUsername.IReply>
 	NetworkConfigSet: UnaryMock<
 		beapi.account.NetworkConfigSet.IRequest,
@@ -240,10 +236,6 @@ export interface IMessengerServiceMock {
 		beapi.messenger.SendContactRequest.IRequest,
 		beapi.messenger.SendContactRequest.IReply
 	>
-	SendReplyOptions: UnaryMock<
-		beapi.messenger.SendReplyOptions.IRequest,
-		beapi.messenger.SendReplyOptions.IReply
-	>
 	SystemInfo: UnaryMock<beapi.messenger.SystemInfo.IRequest, beapi.messenger.SystemInfo.IReply>
 	EchoTest: ResponseStreamMock<beapi.messenger.EchoTest.IRequest, beapi.messenger.EchoTest.IReply>
 	EchoDuplexTest: never
@@ -314,18 +306,6 @@ export interface IMessengerServiceMock {
 		beapi.messenger.InstanceExportData.IRequest,
 		beapi.messenger.InstanceExportData.IReply
 	>
-	MediaPrepare: RequestStreamMock<
-		beapi.messenger.MediaPrepare.IRequest,
-		beapi.messenger.MediaPrepare.IReply
-	>
-	MediaRetrieve: ResponseStreamMock<
-		beapi.messenger.MediaRetrieve.IRequest,
-		beapi.messenger.MediaRetrieve.IReply
-	>
-	MediaGetRelated: UnaryMock<
-		beapi.messenger.MediaGetRelated.IRequest,
-		beapi.messenger.MediaGetRelated.IReply
-	>
 	MessageSearch: UnaryMock<
 		beapi.messenger.MessageSearch.IRequest,
 		beapi.messenger.MessageSearch.IReply
@@ -355,8 +335,4 @@ export interface IMessengerServiceMock {
 		beapi.messenger.PushTokenSharedForConversation.IReply
 	>
 	PushReceive: UnaryMock<beapi.messenger.PushReceive.IRequest, beapi.messenger.PushReceive.IReply>
-	InteractionReactionsForEmoji: UnaryMock<
-		beapi.messenger.InteractionReactionsForEmoji.IRequest,
-		beapi.messenger.InteractionReactionsForEmoji.IReply
-	>
 }
