@@ -9,6 +9,7 @@ import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
 import { useStyles } from '@berty/contexts/styles'
 import { useProfileNotification, useThemeColor } from '@berty/hooks'
 import { useNavigation } from '@berty/navigation'
+import * as testIDs from '@berty/utils/testing/testIDs.json'
 
 import { UnreadCount } from './UnreadCount'
 
@@ -21,32 +22,20 @@ export const HomeHeader: React.FC<
 		onChange: (value: string) => void
 		refresh: boolean
 		setRefresh: (value: boolean) => void
-		onLongPress: React.Dispatch<React.SetStateAction<boolean>>
-		isMultiAccount: boolean
 	}
-> = ({
-	hasRequests,
-	scrollRef,
-	isOnTop,
-	value,
-	onChange,
-	refresh,
-	setRefresh,
-	onLongPress,
-	isMultiAccount,
-}) => {
+> = ({ hasRequests, scrollRef, isOnTop, value, onChange, refresh, setRefresh }) => {
 	const { border, width, height, padding, margin } = useStyles()
 	const { scaleSize } = useAppDimensions()
 	const colors = useThemeColor()
 	const { navigate } = useNavigation()
 	const notifs = useProfileNotification()
 	const { t } = useTranslation()
-	const animate = useRef<any>(null)
+	const animate = useRef<LottieView>(null)
 
 	useEffect(() => {
 		if (refresh) {
 			setRefresh(false)
-			animate.current.play()
+			animate.current?.play()
 		}
 	}, [refresh, setRefresh, animate])
 
@@ -83,7 +72,7 @@ export const HomeHeader: React.FC<
 							<TouchableOpacity
 								activeOpacity={1}
 								onPress={() => {
-									animate.current.play()
+									animate.current?.play()
 									scrollRef.current?.scrollTo({ y: 0, animated: true })
 								}}
 							>
@@ -100,7 +89,7 @@ export const HomeHeader: React.FC<
 								value={value}
 								onChangeText={onChange}
 								placeholder={t('main.home.input-placeholder')}
-								accessibilityLabel={t('main.home.input-placeholder')}
+								testID={testIDs['home-input']}
 								iconName='search-outline'
 							/>
 						</View>
@@ -112,14 +101,7 @@ export const HomeHeader: React.FC<
 								alignItems: 'center',
 							}}
 							onPress={() => {
-								if (isMultiAccount) {
-									onLongPress(false)
-								} else {
-									navigate('Settings.Home')
-								}
-							}}
-							onLongPress={() => {
-								onLongPress(true)
+								navigate('Settings.Home')
 							}}
 						>
 							<AccountAvatar size={35} />
