@@ -2,16 +2,16 @@ import React from 'react'
 import { useTranslation } from 'react-i18next'
 import { ScrollView, View } from 'react-native'
 
-import { ButtonSettingV2, Section } from '@berty/components/shared-components'
+import { DividerItem, MenuItemWithIcon, ItemSection } from '@berty/components'
 import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
+import { useThemeColor } from '@berty/hooks'
 import { ScreenFC, useNavigation } from '@berty/navigation'
-import { useThemeColor } from '@berty/store'
 
 export const AboutBerty: ScreenFC<'Settings.AboutBerty'> = () => {
 	const { scaleSize } = useAppDimensions()
 	const colors = useThemeColor()
 	const { navigate } = useNavigation()
-	const { t }: { t: any } = useTranslation()
+	const { t } = useTranslation()
 
 	return (
 		<View style={{ backgroundColor: colors['secondary-background'], flex: 1 }}>
@@ -20,24 +20,29 @@ export const AboutBerty: ScreenFC<'Settings.AboutBerty'> = () => {
 				contentContainerStyle={{ paddingBottom: 12 * scaleSize }}
 				showsVerticalScrollIndicator={false}
 			>
-				<Section>
-					<ButtonSettingV2
-						text={t('settings.about.faq-button')}
+				<ItemSection>
+					<MenuItemWithIcon
+						iconName='question-mark-circle-outline'
 						onPress={() => navigate('Settings.Faq')}
-						icon='question-mark-circle-outline'
-					/>
-					<ButtonSettingV2
-						text={t('settings.about.roadmap-button')}
-						icon='map-outline'
-						onPress={() => navigate('Settings.Roadmap')}
-					/>
-					<ButtonSettingV2
-						text={t('settings.about.policy-button')}
-						icon='lock-outline'
+					>
+						{t('settings.about.faq-button')}
+					</MenuItemWithIcon>
+					<DividerItem />
+					<MenuItemWithIcon iconName='map-outline' onPress={() => navigate('Settings.Roadmap')}>
+						{t('settings.about.roadmap-button')}
+					</MenuItemWithIcon>
+					<DividerItem />
+					<MenuItemWithIcon
+						iconName='lock-outline'
 						onPress={() => navigate('Settings.PrivacyPolicy')}
-					/>
-					<ButtonSettingV2 text={t('settings.about.license-button')} icon='info-outline' last />
-				</Section>
+					>
+						{t('settings.about.policy-button')}
+					</MenuItemWithIcon>
+					<DividerItem />
+					<MenuItemWithIcon iconName='info-outline'>
+						{t('settings.about.license-button')}
+					</MenuItemWithIcon>
+				</ItemSection>
 			</ScrollView>
 		</View>
 	)
