@@ -13,8 +13,6 @@ import {
 	BootstrapAltDropdown,
 	RelayAltDropdown,
 } from '@berty/components'
-import { useAppDimensions } from '@berty/contexts/app-dimensions.context'
-import { ModalProvider } from '@berty/contexts/modal.context'
 import { useAppDispatch, useSyncNetworkConfigOnScreenRemoved, useThemeColor } from '@berty/hooks'
 import { ScreenFC, useNavigation } from '@berty/navigation'
 import {
@@ -22,8 +20,9 @@ import {
 	selectEditedNetworkConfig,
 	setCurrentNetworkConfig,
 } from '@berty/redux/reducers/networkConfig.reducer'
-import { checkProximityPermission } from '@berty/utils/react-native/checkPermissions'
+import { checkProximityPermission } from '@berty/utils/permissions/checkPermissions'
 import { IOSOnlyKeyboardAvoidingView } from '@berty/utils/react-native/keyboardAvoiding'
+import * as testIDs from '@berty/utils/testing/testIDs.json'
 
 const Proximity: React.FC = () => {
 	const { navigate } = useNavigation()
@@ -37,6 +36,7 @@ const Proximity: React.FC = () => {
 			{Platform.OS !== 'web' && (
 				<>
 					<MenuToggle
+						testID={testIDs['ble-button']}
 						isToggleOn={
 							blePerm === 'granted' &&
 							networkConfig?.bluetoothLe === beapi.account.NetworkConfig.Flag.Enabled
@@ -60,6 +60,7 @@ const Proximity: React.FC = () => {
 			{Platform.OS === 'ios' && (
 				<>
 					<MenuToggle
+						testID={testIDs['mc-button']}
 						isToggleOn={
 							blePerm === 'granted' &&
 							networkConfig?.appleMultipeerConnectivity === beapi.account.NetworkConfig.Flag.Enabled
@@ -83,6 +84,7 @@ const Proximity: React.FC = () => {
 			{Platform.OS === 'android' && (
 				<>
 					<MenuToggle
+						testID={testIDs['nearby-button']}
 						isToggleOn={
 							blePerm === 'granted' &&
 							networkConfig?.androidNearby === beapi.account.NetworkConfig.Flag.Enabled
@@ -104,6 +106,7 @@ const Proximity: React.FC = () => {
 				</>
 			)}
 			<MenuToggle
+				testID={testIDs['mdns-button']}
 				isToggleOn={networkConfig?.mdns === beapi.account.NetworkConfig.Flag.Enabled}
 				onPress={async () => {
 					dispatch(
@@ -124,7 +127,6 @@ const Proximity: React.FC = () => {
 }
 
 const NetworkBody: React.FC = () => {
-	const { scaleSize } = useAppDimensions()
 	const colors = useThemeColor()
 	const { t } = useTranslation()
 	const dispatch = useDispatch()
@@ -134,7 +136,7 @@ const NetworkBody: React.FC = () => {
 		<View style={{ backgroundColor: colors['secondary-background'], flex: 1 }}>
 			<ScrollView
 				bounces={false}
-				contentContainerStyle={{ paddingBottom: 12 * scaleSize }}
+				contentContainerStyle={{ paddingBottom: 12 }}
 				showsVerticalScrollIndicator={false}
 			>
 				{/*
@@ -187,14 +189,12 @@ export const Network: ScreenFC<'Settings.Network'> = () => {
 	useSyncNetworkConfigOnScreenRemoved()
 
 	return (
-		<ModalProvider>
-			<IOSOnlyKeyboardAvoidingView
-				behavior='padding'
-				keyboardVerticalOffset={headerHeight}
-				style={[{ flex: 1 }]}
-			>
-				<NetworkBody />
-			</IOSOnlyKeyboardAvoidingView>
-		</ModalProvider>
+		<IOSOnlyKeyboardAvoidingView
+			behavior='padding'
+			keyboardVerticalOffset={headerHeight}
+			style={[{ flex: 1 }]}
+		>
+			<NetworkBody />
+		</IOSOnlyKeyboardAvoidingView>
 	)
 }
