@@ -1,35 +1,25 @@
 import { Icon } from '@ui-kitten/components'
 import React, { useReducer } from 'react'
 import { useTranslation } from 'react-i18next'
-import { Pressable, View } from 'react-native'
-import ImagePicker, { ImageOrVideo } from 'react-native-image-crop-picker'
+import { View } from 'react-native'
 import { useSelector } from 'react-redux'
 
 import { SecondaryButton, SmallInput } from '@berty/components'
 import { UnifiedText } from '@berty/components/shared-components/UnifiedText'
-import { useModal } from '@berty/contexts/modal.context'
 import { useStyles } from '@berty/contexts/styles'
 import { useAccount, useMessengerClient, useThemeColor, useUpdateAccount } from '@berty/hooks'
 import { selectSelectedAccount } from '@berty/redux/reducers/ui.reducer'
 
-import { ImagePic } from './ImagePic'
-import { ImagePlaceholder } from './ImagePlaceholder'
-
 type State = {
 	saving: boolean
 	name?: string
 	err?: any
-	pic?: ImageOrVideo
 }
 
 type Action =
 	| {
 			type: 'SAVE'
 	  }
-	| {
-			type: 'SET_PICTURE'
-			pic: ImageOrVideo
-	  }
 	| {
 			type: 'SET_NAME'
 			name: string
@@ -46,9 +36,6 @@ const reducer = (prevState: State, action: Action): State => {
 			state.saving = true
 			delete state.err
 			return state
-		case 'SET_PICTURE':
-			state.pic = action.pic
-			return state
 		case 'SET_NAME':
 			state.name = action.name
 			return state
@@ -65,12 +52,15 @@ const initialState: State = {
 	saving: false,
 }
 
-export const EditMyProfile: React.FC = () => {
+interface EditProfileProps {
+	hide: () => void
+}
+
+export const EditMyProfile: React.FC<EditProfileProps> = ({ hide }) => {
 	const colors = useThemeColor()
 	const { t } = useTranslation()
 	const client = useMessengerClient()
 	const selectedAccount = useSelector(selectSelectedAccount)
-	const { hide } = useModal()
 	const updateAccount = useUpdateAccount()
 
 	const account = useAccount()
@@ -79,27 +69,7 @@ export const EditMyProfile: React.FC = () => {
 		...initialState,
 		name: account.displayName || undefined,
 	})
-
-	const handlePicturePressed = async () => {
-		try {
-			const pic = await ImagePicker.openPicker({
-				width: 400,
-				height: 400,
-				cropping: true,
-				cropperCircleOverlay: true,
-				mediaType: 'photo',
-			})
-			if (pic) {
-				localDispatch({ type: 'SET_PICTURE', pic })
-			}
-		} catch (err: any) {
-			if (err?.code !== 'E_PICKER_CANCELLED') {
-				localDispatch({ type: 'SET_ERROR', err })
-			}
-		}
-	}
-
-	const avatarURI = state.pic?.path
+	const isValidName = state.name && state.name.trim() && state.name !== account.displayName
 
 	const handleSave = async () => {
 		try {
@@ -108,28 +78,7 @@ export const EditMyProfile: React.FC = () => {
 			const update: any = {}
 			let updated = false
 
-			if (state.pic) {
-				const stream = await client?.mediaPrepare({})
-				if (!stream) {
-					throw new Error('failed to open prepareAttachment stream')
-				}
-				await stream.emit({
-					info: {
-						mimeType: state.pic.mime,
-						filename: state.pic.filename,
-						displayName: state.pic.filename || 'picture',
-					},
-					uri: avatarURI,
-				})
-				const reply = await stream.stopAndRecv()
-				if (!reply?.cid) {
-					throw new Error('invalid PrepareAttachment reply, missing cid')
-				}
-				update.avatarCid = reply.cid
-				updated = true
-			}
-
-			if (state.name && state.name !== account.displayName) {
+			if (isValidName) {
 				update.displayName = state.name
 				updated = true
 			}
@@ -153,15 +102,12 @@ export const EditMyProfile: React.FC = () => {
 	const { padding, margin, row, flex, text } = useStyles()
 
 	return (
-		<View>
+		<View style={[padding.horizontal.big, margin.top.small]}>
 			<UnifiedText style={[margin.small, margin.bottom.medium, text.size.huge, text.bold]}>
 				{t('settings.edit-profile.title')}
 			</UnifiedText>
 			<View style={[{ flexDirection: 'row', alignItems: 'center' }]}>
-				<Pressable onPress={handlePicturePressed}>
-					{state.pic ? <ImagePic avatarURI={avatarURI} /> : <ImagePlaceholder />}
-				</Pressable>
-				<View style={[flex.tiny, margin.left.medium]}>
+				<View style={[flex.tiny, margin.left.medium, margin.bottom.small]}>
 					<SmallInput
 						value={state.name}
 						onChangeText={name => localDispatch({ type: 'SET_NAME', name })}
@@ -180,7 +126,7 @@ export const EditMyProfile: React.FC = () => {
 					<UnifiedText
 						style={[margin.left.medium, text.size.scale(11), { color: colors['secondary-text'] }]}
 					>
-						{t('settings.edit-profile.qr-will-update') as any}
+						{t('settings.edit-profile.qr-will-update')}
 					</UnifiedText>
 				</View>
 				<View style={[padding.top.small, row.left]}>
@@ -188,7 +134,7 @@ export const EditMyProfile: React.FC = () => {
 					<UnifiedText
 						style={[margin.left.medium, text.size.scale(11), { color: colors['secondary-text'] }]}
 					>
-						{t('settings.edit-profile.ocr-wont-update') as any}
+						{t('settings.edit-profile.ocr-wont-update')}
 					</UnifiedText>
 				</View>
 			</View>
@@ -207,9 +153,7 @@ export const EditMyProfile: React.FC = () => {
 				</View>
 			)}
 			<SecondaryButton loading={state.saving} onPress={handleSave}>
-				{(state.name && state.name !== account.displayName) || state.pic
-					? t('settings.edit-profile.save')
-					: (t('settings.edit-profile.cancel') as any)}
+				{isValidName ? t('settings.edit-profile.save') : t('settings.edit-profile.cancel')}
 			</SecondaryButton>
 		</View>
 	)
