@@ -1,7 +1,5 @@
-export { ServicesAuth } from './ServicesAuth/ServicesAuth'
 export { AboutBerty } from './AboutBerty/AboutBerty'
 export { TermsOfUse } from './TermsOfUse/TermsOfUse'
-export { BertyServices } from './BertyServices/BertyServices'
 export { Roadmap } from './Roadmap/Roadmap'
 export { Faq } from './Faq/Faq'
 export { PrivacyPolicy } from './PrivacyPolicy/PrivacyPolicy'
@@ -22,4 +20,4 @@ export { DevText } from './DevText/DevText'
 export { SystemInfo } from './SystemInfo/SystemInfo'
 export { AddDevConversations } from './AddDevConversations/AddDevConversations'
 export { FakeData } from './FakeData/FakeData'
-export { NetworkMap } from './NetworkMap/NetworkMap'
+export { Permissions } from './Permissions/Permissions'
